==> chessboard-6.x-1.0.tar.gz: chessboard/chessboard_render.php <==
<?php
// $Id: chessboard_render.php,v 1.16.2.10 2010/09/19 19:48:28 erica Exp $

/**
 * @file
 * Theme related functions for the Chessboard Renderer module.
 */

/*================================*/
/* Configuration                  */
/*================================*/

function chessboard_image_path($path) {
  global $chessboard_image_path;
  $chessboard_image_path = $path;
}


/*================================*/
/* Routines                       */
/*================================*/

function chessboard_border_filename($border, $chessboard_image_path = NULL) {
  // $border: T, B, L, R, TL, TR, BL, BR
  if (!isset($chessboard_image_path)) {
    $chessboard_image_path = $GLOBALS['chessboard_image_path'];
  }
  switch ($border) {
    case 'T':
    case 'B':
      return $chessboard_image_path . 'h.png';
    case 'L':
    case 'R':
      return $chessboard_image_path . 'v.png';
    default:
      return $chessboard_image_path . 'c.png';
  }
}


function chessboard_piece_filename($piece, $square_color, $chessboard_image_path = NULL) {
  // $piece        : KQBNRPkqbnrp-
  // $square_color : 0 1
  if (!isset($chessboard_image_path)) {
    $chessboard_image_path = $GLOBALS['chessboard_image_path'];
  }
  switch ($piece) {
    case 'x':
      $name = 'xx';
      break;
    case '-':
      $name = '';
      break;
    default:
      $name = strtolower($piece) . (ctype_lower($piece) ? 'd' : 'l');
      break;
  }

  return $chessboard_image_path . $name . ($square_color ? 'd' : 'l') . '.png';
}

function chessboard_render($content) {
  global $chessboard_image_path;

  if (!isset($chessboard_image_path)) {
    $image_directory_path = NULL;
  }
  elseif (strpos($chessboard_image_path, base_path()) === 0) {
    $image_directory_path = trim(substr($chessboard_image_path, strlen(base_path())), '\\/');
  }
  else {
    $image_directory_path = trim($chessboard_image_path, '\\/');
  }
  $item = array(
    'value' => $content,
  );
  $node = NULL;
  $field = array();
  $items = array($item);
  chessboard_field('sanitize', $node, $field, $items, FALSE, FALSE);
  $element = array(
    '#theme' => 'chessboard',
    '#item' => $items[0],
    '#weight' => 0,
    '#image_directory_path' => $image_directory_path,
  );
  $output = chessboard_render_elements($element);
  return $output;
}

/**
 * Formats Chessboard Renderer notation syntax in HTML.
 *
 * @param $element
 *    An associative array containing items (chessboards) as children keyed by delta.
 *
 * @ingroup themable
 */
function theme_chessboard_formatter_chessboard_default($element) {
  $items = array();
  foreach (element_children($element) as $key) {
    $items[$key] = $element[$key]['#item'];
  }
  $element = chessboard_formatter_view($items);
  $output = chessboard_render_elements($element);
  return $output;
}

function template_preprocess_chessboard(&$variables) {
  static $tables_xhtml = array();

  if (!isset($variables['element']['#image_directory_path'])) {
    $variables['element']['#image_directory_path'] = drupal_get_path('module', 'chessboard') . '/default';
    $getsize = TRUE;
  }
  else {
    $getsize_test_path = chessboard_piece_filename('-', 0, $variables['element']['#image_directory_path'] . '/');
    $getsize = is_file($getsize_test_path) && (list($width, $height) = @getimagesize($getsize_test_path));
  }
  $image_directory_path = $variables['element']['#image_directory_path'];
  if (!isset($tables_xhtml[$image_directory_path])) {
    // Construct the translation table

    // Empty and marked squares
    $table_xhtml = array(
      '-0' => theme('image', chessboard_piece_filename('-', 0, $image_directory_path . '/'), '-', NULL, array('class' => 'chessboard-square'), $getsize),
      '-1' => theme('image', chessboard_piece_filename('-', 1, $image_directory_path . '/'), '-', NULL, array('class' => 'chessboard-square'), $getsize),
      'x0' => theme('image', chessboard_piece_filename('x', 0, $image_directory_path . '/'), 'x', NULL, array('class' => 'chessboard-square'), $getsize),
      'x1' => theme('image', chessboard_piece_filename('x', 1, $image_directory_path . '/'), 'x', NULL, array('class' => 'chessboard-square'), $getsize),
    );

    // Pieces
    $pieces = 'kqbnrp';
    for ($i=0; $i<6; $i++) {
      $piece = $pieces[$i];
      $table_xhtml += array(
        strtoupper($piece) . '0' => theme('image', chessboard_piece_filename(strtoupper($piece), 0, $image_directory_path . '/'), strtoupper($piece), NULL, array('class' => 'chessboard-square'), $getsize),
        strtoupper($piece) . '1' => theme('image', chessboard_piece_filename(strtoupper($piece), 1, $image_directory_path . '/'), strtoupper($piece), NULL, array('class' => 'chessboard-square'), $getsize),
        $piece . '0' => theme('image', chessboard_piece_filename($piece, 0, $image_directory_path . '/'), $piece, NULL, array('class' => 'chessboard-square'), $getsize),
        $piece . '1' => theme('image', chessboard_piece_filename($piece, 1, $image_directory_path . '/'), $piece, NULL, array('class' => 'chessboard-square'), $getsize),
      );
    }

    // Borders
    $table_xhtml += array(
      'T' => theme('image', chessboard_border_filename('T', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-h'), $getsize),
      'B' => theme('image', chessboard_border_filename('B', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-h'), $getsize),
      'L' => theme('image', chessboard_border_filename('L', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-v'), $getsize),
      'R' => theme('image', chessboard_border_filename('R', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-v'), $getsize),
      'TL' => theme('image', chessboard_border_filename('TL', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-c'), $getsize),
      'TR' => theme('image', chessboard_border_filename('TR', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-c'), $getsize),
      'BL' => theme('image', chessboard_border_filename('BL', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-c'), $getsize),
      'BR' => theme('image', chessboard_border_filename('BR', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-c'), $getsize),
    );
    $tables_xhtml[$image_directory_path] = $table_xhtml;
  }
  $variables['table_xhtml'] = $tables_xhtml[$image_directory_path];
  // For convenience.
  $variables['file_max'] = $variables['element']['#item']['file_max'];
  $variables['square_color_first'] = $variables['element']['#item']['square_color_first'];
  $variables['border'] = $variables['element']['#item']['border'];
  $variables['board'] = $variables['element']['#item']['board'];
}

==> chessboard-6.x-1.1.tar.gz: chessboard/chessboard_render.php <==
<?php
// $Id: chessboard_render.php,v 1.16.2.11 2010/11/30 21:12:24 erica Exp $

/**
 * @file
 * Theme related functions for the Chessboard Renderer module.
 */

/*================================*/
/* Configuration                  */
/*================================*/

function chessboard_image_path($path) {
  global $chessboard_image_path;
  $chessboard_image_path = $path;
}


/*================================*/
/* Routines                       */
/*================================*/

function chessboard_border_filename($border, $chessboard_image_path = NULL) {
  // $border: T, B, L, R, TL, TR, BL, BR
  if (!isset($chessboard_image_path)) {
    $chessboard_image_path = $GLOBALS['chessboard_image_path'];
  }
  switch ($border) {
    case 'T':
    case 'B':
      return $chessboard_image_path . 'h.png';
    case 'L':
    case 'R':
      return $chessboard_image_path . 'v.png';
    default:
      return $chessboard_image_path . 'c.png';
  }
}


function chessboard_piece_filename($piece, $square_color, $chessboard_image_path = NULL) {
  // $piece        : KQBNRPkqbnrp-
  // $square_color : 0 1
  if (!isset($chessboard_image_path)) {
    $chessboard_image_path = $GLOBALS['chessboard_image_path'];
  }
  switch ($piece) {
    case 'x':
      $name = 'xx';
      break;
    case '-':
      $name = '';
      break;
    default:
      $name = strtolower($piece) . (ctype_lower($piece) ? 'd' : 'l');
      break;
  }

  return $chessboard_image_path . $name . ($square_color ? 'd' : 'l') . '.png';
}

function chessboard_render($content) {
  global $chessboard_image_path;

  if (!isset($chessboard_image_path)) {
    $image_directory_path = NULL;
  }
  elseif (strpos($chessboard_image_path, base_path()) === 0) {
    $image_directory_path = trim(substr($chessboard_image_path, strlen(base_path())), '\\/');
  }
  else {
    $image_directory_path = trim($chessboard_image_path, '\\/');
  }
  $item = array(
    'value' => $content,
  );
  $node = NULL;
  $field = array();
  $items = array($item);
  chessboard_field('sanitize', $node, $field, $items, FALSE, FALSE);
  $element = array(
    '#theme' => 'chessboard',
    '#item' => $items[0],
    '#weight' => 0,
    '#image_directory_path' => $image_directory_path,
  );
  $output = _chessboard_render_elements($element);
  return $output;
}

/**
 * Formats Chessboard Renderer notation syntax in HTML.
 *
 * @param $element
 *    An associative array containing items (chessboards) as children keyed by delta.
 *
 * @ingroup themable
 */
function theme_chessboard_formatter_chessboard_default($element) {
  $items = array();
  foreach (element_children($element) as $key) {
    $items[$key] = $element[$key]['#item'];
  }
  $element = _chessboard_formatter_view($items);
  $output = _chessboard_render_elements($element);
  return $output;
}

function template_preprocess_chessboard(&$variables) {
  static $tables_xhtml = array();

  if (!isset($variables['element']['#image_directory_path'])) {
    $variables['element']['#image_directory_path'] = drupal_get_path('module', 'chessboard') . '/default';
    $getsize = TRUE;
  }
  else {
    $getsize_test_path = chessboard_piece_filename('-', 0, $variables['element']['#image_directory_path'] . '/');
    $getsize = is_file($getsize_test_path) && (list($width, $height) = @getimagesize($getsize_test_path));
  }
  $image_directory_path = $variables['element']['#image_directory_path'];
  if (!isset($tables_xhtml[$image_directory_path])) {
    // Construct the translation table

    // Empty and marked squares
    $table_xhtml = array(
      '-0' => theme('image', chessboard_piece_filename('-', 0, $image_directory_path . '/'), '-', NULL, array('class' => 'chessboard-square'), $getsize),
      '-1' => theme('image', chessboard_piece_filename('-', 1, $image_directory_path . '/'), '-', NULL, array('class' => 'chessboard-square'), $getsize),
      'x0' => theme('image', chessboard_piece_filename('x', 0, $image_directory_path . '/'), 'x', NULL, array('class' => 'chessboard-square'), $getsize),
      'x1' => theme('image', chessboard_piece_filename('x', 1, $image_directory_path . '/'), 'x', NULL, array('class' => 'chessboard-square'), $getsize),
    );

    // Pieces
    $pieces = 'kqbnrp';
    for ($i=0; $i<6; $i++) {
      $piece = $pieces[$i];
      $table_xhtml += array(
        strtoupper($piece) . '0' => theme('image', chessboard_piece_filename(strtoupper($piece), 0, $image_directory_path . '/'), strtoupper($piece), NULL, array('class' => 'chessboard-square'), $getsize),
        strtoupper($piece) . '1' => theme('image', chessboard_piece_filename(strtoupper($piece), 1, $image_directory_path . '/'), strtoupper($piece), NULL, array('class' => 'chessboard-square'), $getsize),
        $piece . '0' => theme('image', chessboard_piece_filename($piece, 0, $image_directory_path . '/'), $piece, NULL, array('class' => 'chessboard-square'), $getsize),
        $piece . '1' => theme('image', chessboard_piece_filename($piece, 1, $image_directory_path . '/'), $piece, NULL, array('class' => 'chessboard-square'), $getsize),
      );
    }

    // Borders
    $table_xhtml += array(
      'T' => theme('image', chessboard_border_filename('T', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-h'), $getsize),
      'B' => theme('image', chessboard_border_filename('B', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-h'), $getsize),
      'L' => theme('image', chessboard_border_filename('L', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-v'), $getsize),
      'R' => theme('image', chessboard_border_filename('R', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-v'), $getsize),
      'TL' => theme('image', chessboard_border_filename('TL', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-c'), $getsize),
      'TR' => theme('image', chessboard_border_filename('TR', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-c'), $getsize),
      'BL' => theme('image', chessboard_border_filename('BL', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-c'), $getsize),
      'BR' => theme('image', chessboard_border_filename('BR', $image_directory_path . '/'), '', NULL, array('class' => 'chessboard-border-c'), $getsize),
    );
    $tables_xhtml[$image_directory_path] = $table_xhtml;
  }
  $variables['table_xhtml'] = $tables_xhtml[$image_directory_path];
  // For convenience.
  $variables['file_max'] = $variables['element']['#item']['file_max'];
  $variables['square_color_first'] = $variables['element']['#item']['square_color_first'];
  $variables['border'] = $variables['element']['#item']['border'];
  $variables['board'] = $variables['element']['#item']['board'];
}
